/**
 * @typedef {import('ipfs-core-types').IPFS} IPFS
 * @typedef {import('multiformats/cid').CID} CID
 * @typedef {import('ipfs-message-port-protocol/cid').EncodedCID} EncodedCID
 * @typedef {import('ipfs-message-port-protocol/dag').EncodedDAGNode} EncodedDAGNode
 * @typedef {import('ipfs-core-types/src/dag').PutOptions} PutOptions
 */
export class DAGService {
    /**
     * @param {IPFS} ipfs
     */
    constructor(ipfs: IPFS);
    ipfs: import("ipfs-core-types").IPFS<any>;
    /**
     * @typedef {object} PutDag
     * @property {EncodedDAGNode} dagNode
     * @property {EncodedCID} [encodedCid]
     *
     * @param {PutOptions & PutDag} query
     * @returns {Promise<EncodedCID>}
     */
    put(query: import("ipfs-core-types/src/dag").PutOptions & {
        dagNode: EncodedDAGNode;
        encodedCid?: import("ipfs-message-port-protocol/cid").EncodedCID | undefined;
    }): Promise<EncodedCID>;
    /**
     * @typedef {object} EncodedGetResult
     * @property {Set<Transferable>} transfer
     * @property {string} [remainderPath]
     * @property {EncodedDAGNode} value
     *
     * @typedef {object} GetDAG
     * @property {EncodedCID} cid
     * @property {string} [path]
     * @property {boolean} [localResolve]
     * @property {number} [timeout]
     * @property {AbortSignal} [signal]
     *
     * @param {GetDAG} query
     * @returns {Promise<EncodedGetResult>}
     */
    get(query: {
        cid: EncodedCID;
        path?: string | undefined;
        localResolve?: boolean | undefined;
        timeout?: number | undefined;
        signal?: AbortSignal | undefined;
    }): Promise<{
        transfer: Set<Transferable>;
        remainderPath?: string | undefined;
        value: EncodedDAGNode;
    }>;
    /**
     * @typedef {object} ResolveQuery
     * @property {EncodedCID|string} cid
     * @property {string} [path]
     * @property {number} [timeout]
     * @property {AbortSignal} [signal]
     *
     * @typedef {object} EncodedResolveResult
     * @property {EncodedCID} cid
     * @property {string} [remainderPath]
     *
     * @param {ResolveQuery} query
     * @returns {Promise<EncodedResolveResult>}
     */
    resolve(query: {
        cid: EncodedCID | string;
        path?: string | undefined;
        timeout?: number | undefined;
        signal?: AbortSignal | undefined;
    }): Promise<{
        cid: EncodedCID;
        remainderPath?: string | undefined;
    }>;
}
export type IPFS = import('ipfs-core-types').IPFS;
export type CID = import('multiformats/cid').CID;
export type EncodedCID = import('ipfs-message-port-protocol/cid').EncodedCID;
export type EncodedDAGNode = import('ipfs-message-port-protocol/dag').EncodedDAGNode;
export type PutOptions = import('ipfs-core-types/src/dag').PutOptions;
//# sourceMappingURL=dag.d.ts.map